"""Centralized constants for the generaltranslation package."""

# From settings/settings.ts
LIBRARY_DEFAULT_LOCALE = "en"
DEFAULT_TIMEOUT = 60_000  # ms

# From settings/settingsUrls.ts
DEFAULT_BASE_URL = "https://api2.gtx.dev"
DEFAULT_CACHE_URL = "https://cdn.gtx.dev"
DEFAULT_RUNTIME_API_URL = "https://runtime2.gtx.dev"

# From translate/api.ts
API_VERSION = "2026-02-18.v1"
